function obj = daad_connect(daad)
%DAAD_CONNECT Verbindung zum Datenerfassungsgert aufbauen
%
%   Auf ihrem PC verfgbare DeviceIDs mit daqlist anzeigen.
%
%   input arguments
%       daad            Bezeichnung des zu verwendenden Datenerfassungsgerts
%                       untersttzt werden
%                       'none'      fr Testzwecke, Messwerte werden aus Datei gelesen
%                       'simideal'  fr Testzwecke, Simulation ohne IQ-Imbalances
%                       'simtx'     fr Testzwecke, Simulation mit senderseitiger IQ-Imbalance
%                       'simrx'     fr Testzwecke, Simulation mit senderseitiger IQ-Imbalance
%                       'simreal'   fr Testzwecke, Simulation mit sender- und empfngerseitiger IQ-Imbalance
%                       'usb6366'   National Instruments USB-6366
%   output arguments
%       obj             Data Acquisition Object
%
%   Data Acquisition Toolbox 
%       S. 4-4 bis 4-8, 6-3, 6-12, 15-13 bis 15-15 
%
%   11.04.2023          T. Weber    

switch daad
    case 'none'
        % Dummy Object erzeugen
        obj.UserData = 'none';
 
        disp('no data acquisition device');

    case 'simideal'
        % Dummy Object erzeugen
        obj.UserData = 'simideal';
        obj.Rate = 1; % normierte Rate 
 
        disp('simulation of ideal data transmission');

    case 'simtx'
        % Dummy Object erzeugen
        obj.UserData = 'simtx';
        obj.Rate = 1; % normierte Rate 
 
        disp('simulation of transmitter side imbalance');

    case 'simrx'
        % Dummy Object erzeugen
        obj.UserData = 'simrx';
        obj.Rate = 1; % normierte Rate 
 
        disp('simulation of receiver side imbalance');

    case 'simreal'
        % Dummy Object erzeugen
        obj.UserData = 'simreal';
        obj.Rate = 1; % normierte Rate 
 
        disp('simulation of transmitter and receiver side imbalance');

    case 'usb6366'
        % Data Acquisition Object erzeugen
        dev = daqlist('ni').DeviceID(1); % es wird die erste gefundene DeviceID verwendet
        obj = daq('ni');
        obj.UserData = 'usb6366';
        ch = addoutput(obj,dev,[0,1],'Voltage');
        ch(1).Range=[-5,5];
        ch(2).Range=[-5,5];
        ch = addinput(obj,dev,[0,4],'Voltage');
        ch(1).Range=[-1,1];
        ch(2).Range=[-1,1];
        addtrigger(obj,'Digital','StartTrigger',append(dev,'/PFI0'),'External'); % Trigger fr den Spektrumanalyzer
        disp('connected to USB-6366');
        
    otherwise
    	error('unsupported data acquisition device');
        
end

end
