%Analyse des Empfangssignals
%
%   11.04.2023          T. Weber    

close all;
clear;

daad = 'none'; % SELECT YOUR DATA ACQUISITION DEVICE HERE

fs = 2e6; % Abtastrate
f = 5e-3; % auf fs normierte Frequenz des Testsignals
k = 200001; % Anzahl der Abtastwerte, entspricht 100 ms Burstdauer

switch questdlg('Parameter des Quadraturmodulators laden','Vorverzerrung','ja','nein','nein')
    case 'ja'
        load('tximbalance');
        
    case 'nein'
        QS = eye(2);
        AS = zeros(2,1);

end

switch questdlg('Parameter des Quadraturdemodulators laden','Entzerrung','ja','nein','nein')
    case 'ja'
        load('rximbalance');
        
    case 'nein'
        QE = eye(2);
        AE = zeros(2,1);

end

% Testsignal, 1 mW total ergeben nach Dmpfung um 10 dB 
% eine totale Mischereingangsleistung von -10 dBm
s = sqrt(1e-3*50)*exp(j*2*pi*f*(0:k-1)); % 1 mW entspricht sqrt(1e-3*50) Volt = 0,2236 Volt an 50 Ohm

% senderseitige IQ-Imbalance kompensieren
s = vorverzerrer(QS,AS,s);

% Verbindung zum Datenerfassungsgert aufbauen
obj = daad_connect(daad);

fs = daad_parameters(obj,fs);

% Burst bertragen
[e,s,time] = daad_transmit(obj,s,'signal.txt');
fs = (numel(time)-1)/(time(end)-time(1));

% Verbindung zum Datenerfassungsgert schlieen
daad_disconnect(obj);

% empfngerseitige IQ-Imbalance kompensieren
e = entzerrer(QE,AE,e);

% Signal zeichnen
figure;
plot(time,abs(e),'r-');
hold on;
plot(time,real(e),'g-');
plot(time,imag(e),'b-');
hold off;

% formatieren
grid on;
xlim([time(1),time(end)]);
xlabel('t/s');
legend('|U(t)|/V','Re(U(t))/V','Im(U(t))/V');

% Spektrum berechnen und zeichnen, Leistungen bezogen auf 1 mW
% 1 mW entspricht sqrt(1e-3*50) Volt = 0,2236 Volt an 50 Ohm
figure;
pwelch(e/sqrt(1e-3*50),gausswin(floor(numel(e)/10),4),[],linspace(-2.5*f*fs,2.5*f*fs,501),fs,'power');

% Spektrum abspeichern
h = findobj(gca,'Type','line');
data = [h.XData(:),h.YData(:)];
save('vorverzerrt.txt','data','-ascii');

% Ortskurve zeichnen
figure;
plot(real(e),imag(e),'b-');

% formatieren
grid on;
axis equal;
axis manual;
xlim([min(real(e)),max(real(e))]);
ylim([min(imag(e)),max(imag(e))]);
xlabel('Re(U)/V');
ylabel('Re(U)/V');
